# <span class="badge package-core"></span> preferences

## Objects

 * <span class="badge object-type-class"></span> [CookiePreferences](./object-CookiePreferences.md)
 * <span class="badge object-type-class"></span> [Preferences](./object-Preferences.md)
 * <span class="badge object-type-class"></span> [QueryHistoryPreference](./object-QueryHistoryPreference.md)
## Builders

 * <span class="badge builder"></span> [CookiePreferences](./builder-CookiePreferences.md)
 * <span class="badge builder"></span> [Preferences](./builder-Preferences.md)
 * <span class="badge builder"></span> [QueryHistoryPreference](./builder-QueryHistoryPreference.md)
